<?php return array(
    'root' => array(
        'name' => 'icinga/icinga-php-thirdparty',
        'pretty_version' => 'dev-main',
        'version' => 'dev-main',
        'reference' => 'a3a9a0f9a8449974ad52dcfbd5b1f1512e6e8bdb',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        'brick/math' => array(
            'pretty_version' => '0.13.1',
            'version' => '0.13.1.0',
            'reference' => 'fc7ed316430118cc7836bf45faff18d5dfc8de04',
            'type' => 'library',
            'install_path' => __DIR__ . '/../brick/math',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'clue/block-react' => array(
            'pretty_version' => 'v1.5.0',
            'version' => '1.5.0.0',
            'reference' => '718b0571a94aa693c6fffc72182e87257ac900f3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/block-react',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'clue/connection-manager-extra' => array(
            'pretty_version' => 'v1.3.0',
            'version' => '1.3.0.0',
            'reference' => '6ddf7da4cd75bf5aa54be13eea7be9aad9e97ada',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/connection-manager-extra',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'clue/http-proxy-react' => array(
            'pretty_version' => 'v1.9.0',
            'version' => '1.9.0.0',
            'reference' => 'f3b02835273036a9370ac1c144b55df8e2b98430',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/http-proxy-react',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'clue/mq-react' => array(
            'pretty_version' => 'v1.7.0',
            'version' => '1.7.0.0',
            'reference' => '0b6b9b097603dd0374a31822021372614df736ea',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/mq-react',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'clue/redis-protocol' => array(
            'pretty_version' => 'v0.3.2',
            'version' => '0.3.2.0',
            'reference' => '6f565332f5531b7722d1e9c445314b91862f6d6c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/redis-protocol',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'clue/redis-react' => array(
            'pretty_version' => 'v2.8.0',
            'version' => '2.8.0.0',
            'reference' => '84569198dfd5564977d2ae6a32de4beb5a24bdca',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/redis-react',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'clue/soap-react' => array(
            'pretty_version' => 'v2.0.0',
            'version' => '2.0.0.0',
            'reference' => 'db2e0ba9b0380ac6c4a34df3f1021d2191d45d45',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/soap-react',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'clue/socket-raw' => array(
            'pretty_version' => 'v1.6.0',
            'version' => '1.6.0.0',
            'reference' => '91e9f619f6769f931454a9882c21ffd7623d06cb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/socket-raw',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'clue/socks-react' => array(
            'pretty_version' => 'v1.4.0',
            'version' => '1.4.0.0',
            'reference' => 'eb3bd2ca5f43fea4b3bc4ef055179e0e6714730d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/socks-react',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'clue/stdio-react' => array(
            'pretty_version' => 'v2.6.0',
            'version' => '2.6.0.0',
            'reference' => 'dfa6c378aabdff718202d4e2453f752c38ea3399',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/stdio-react',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'clue/term-react' => array(
            'pretty_version' => 'v1.4.0',
            'version' => '1.4.0.0',
            'reference' => '00f297dc597eaee2ebf98af8f27cca5d21d60fa3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/term-react',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'clue/utf8-react' => array(
            'pretty_version' => 'v1.3.0',
            'version' => '1.3.0.0',
            'reference' => 'd5cd04d39cb5457aa5df830b7c4b301d2694217e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../clue/utf8-react',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'components/jquery' => array(
            'pretty_version' => 'v3.7.1',
            'version' => '3.7.1.0',
            'reference' => '8edc7785239bb8c2ad2b83302b856a1d61de60e7',
            'type' => 'component',
            'install_path' => __DIR__ . '/../components/jquery',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'cweagans/composer-patches' => array(
            'pretty_version' => '1.7.3',
            'version' => '1.7.3.0',
            'reference' => 'e190d4466fe2b103a55467dfa83fc2fecfcaf2db',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../cweagans/composer-patches',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/collections' => array(
            'pretty_version' => '2.3.0',
            'version' => '2.3.0.0',
            'reference' => '2eb07e5953eed811ce1b309a7478a3b236f2273d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/collections',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/deprecations' => array(
            'pretty_version' => '1.1.5',
            'version' => '1.1.5.0',
            'reference' => '459c2f5dd3d6a4633d3b5f46ee2b1c40f57d3f38',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/deprecations',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dompdf/dompdf' => array(
            'pretty_version' => 'v3.1.0',
            'version' => '3.1.0.0',
            'reference' => 'a51bd7a063a65499446919286fb18b518177155a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dompdf/dompdf',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dompdf/php-font-lib' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => '6137b7d4232b7f16c882c75e4ca3991dbcf6fe2d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dompdf/php-font-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dompdf/php-svg-lib' => array(
            'pretty_version' => '1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'eb045e518185298eb6ff8d80d0d0c6b17aecd9af',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dompdf/php-svg-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dragonmantank/cron-expression' => array(
            'pretty_version' => 'v3.4.0',
            'version' => '3.4.0.0',
            'reference' => '8c784d071debd117328803d86b2097615b457500',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dragonmantank/cron-expression',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'erusev/parsedown' => array(
            'pretty_version' => '1.7.4',
            'version' => '1.7.4.0',
            'reference' => 'cb17b6477dfff935958ba01325f2e8a2bfa6dab3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../erusev/parsedown',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'evenement/evenement' => array(
            'pretty_version' => 'v3.0.2',
            'version' => '3.0.2.0',
            'reference' => '0a16b0d71ab13284339abb99d9d2bd813640efbc',
            'type' => 'library',
            'install_path' => __DIR__ . '/../evenement/evenement',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ezyang/htmlpurifier' => array(
            'pretty_version' => 'v4.18.0',
            'version' => '4.18.0.0',
            'reference' => 'cb56001e54359df7ae76dc522d08845dc741621b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ezyang/htmlpurifier',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fig/http-message-util' => array(
            'pretty_version' => '1.1.5',
            'version' => '1.1.5.0',
            'reference' => '9d94dc0154230ac39e5bf89398b324a86f63f765',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fig/http-message-util',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/guzzle' => array(
            'pretty_version' => '7.9.3',
            'version' => '7.9.3.0',
            'reference' => '7b2f29fe81dc4da0ca0ea7d42107a0845946ea77',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/guzzle',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/promises' => array(
            'pretty_version' => '2.2.0',
            'version' => '2.2.0.0',
            'reference' => '7c69f28996b0a6920945dd20b3857e499d9ca96c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/promises',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '2.7.1',
            'version' => '2.7.1.0',
            'reference' => 'c2270caaabe631b3b44c85f99e5a04bbb8060d16',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'icinga/icinga-php-thirdparty' => array(
            'pretty_version' => 'dev-main',
            'version' => 'dev-main',
            'reference' => 'a3a9a0f9a8449974ad52dcfbd5b1f1512e6e8bdb',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'jfcherng/php-color-output' => array(
            'pretty_version' => '3.0.0',
            'version' => '3.0.0.0',
            'reference' => '6c7bf16686cc6a291647fcb87491640a2d5edd20',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jfcherng/php-color-output',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'jfcherng/php-diff' => array(
            'pretty_version' => '6.16.2',
            'version' => '6.16.2.0',
            'reference' => '7f46bcfc582e81769237d0b3f6b8a548efe8799d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jfcherng/php-diff',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'jfcherng/php-mb-string' => array(
            'pretty_version' => '2.0.1',
            'version' => '2.0.1.0',
            'reference' => '8407bfefde47849c9e7c9594e6de2ac85a0f845d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jfcherng/php-mb-string',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'jfcherng/php-sequence-matcher' => array(
            'pretty_version' => '4.0.3',
            'version' => '4.0.3.0',
            'reference' => 'd2038ac29627340a7458609072a8ba355e80ec5b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jfcherng/php-sequence-matcher',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'masterminds/html5' => array(
            'pretty_version' => '2.9.0',
            'version' => '2.9.0.0',
            'reference' => 'f5ac2c0b0a2eefca70b2ce32a5809992227e75a6',
            'type' => 'library',
            'install_path' => __DIR__ . '/../masterminds/html5',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mtdowling/cron-expression' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '^1.0',
            ),
        ),
        'predis/predis' => array(
            'pretty_version' => 'v3.0.1',
            'version' => '3.0.1.0',
            'reference' => '34fb0a7da0330df1bab4280fcac4afdeeccc3edf',
            'type' => 'library',
            'install_path' => __DIR__ . '/../predis/predis',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client' => array(
            'pretty_version' => '1.0.3',
            'version' => '1.0.3.0',
            'reference' => 'bb5906edc1c324c9a05aa0873d40117941e5fa90',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '2b4765fddfe3b508ac62f829e852b1501d3f6e8a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-message' => array(
            'pretty_version' => '1.1',
            'version' => '1.1.0.0',
            'reference' => 'cb6ce4845ce34a8ad9e68117c10ee90a29919eba',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/log' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'reference' => 'd49695b909c3b7628b6289db5479a1c204601f11',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ramsey/collection' => array(
            'pretty_version' => '2.1.1',
            'version' => '2.1.1.0',
            'reference' => '344572933ad0181accbf4ba763e85a0306a8c5e2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ramsey/collection',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ramsey/uuid' => array(
            'pretty_version' => '4.9.0',
            'version' => '4.9.0.0',
            'reference' => '4e0e23cc785f0724a0e838279a9eb03f28b092a0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ramsey/uuid',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/cache' => array(
            'pretty_version' => 'v1.2.0',
            'version' => '1.2.0.0',
            'reference' => 'd47c472b64aa5608225f47965a484b75c7817d5b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/cache',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/child-process' => array(
            'pretty_version' => 'v0.6.6',
            'version' => '0.6.6.0',
            'reference' => '1721e2b93d89b745664353b9cfc8f155ba8a6159',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/child-process',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/datagram' => array(
            'pretty_version' => 'v1.10.0',
            'version' => '1.10.0.0',
            'reference' => '9236e1f5a67a6029be17d551e9858c487836c301',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/datagram',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/dns' => array(
            'pretty_version' => 'v1.13.0',
            'version' => '1.13.0.0',
            'reference' => 'eb8ae001b5a455665c89c1df97f6fb682f8fb0f5',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/dns',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/event-loop' => array(
            'pretty_version' => 'v1.5.0',
            'version' => '1.5.0.0',
            'reference' => 'bbe0bd8c51ffc05ee43f1729087ed3bdf7d53354',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/event-loop',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/http' => array(
            'pretty_version' => 'v1.11.0',
            'version' => '1.11.0.0',
            'reference' => '8db02de41dcca82037367f67a2d4be365b1c4db9',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/http',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/promise' => array(
            'pretty_version' => 'v2.11.0',
            'version' => '2.11.0.0',
            'reference' => '1a8460931ea36dc5c76838fec5734d55c88c6831',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/promise',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/promise-stream' => array(
            'pretty_version' => 'v1.7.0',
            'version' => '1.7.0.0',
            'reference' => '5c7ec3450f558deb779742e33967d837e2db7871',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/promise-stream',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/promise-timer' => array(
            'pretty_version' => 'v1.11.0',
            'version' => '1.11.0.0',
            'reference' => '4f70306ed66b8b44768941ca7f142092600fafc1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/promise-timer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/socket' => array(
            'pretty_version' => 'v1.16.0',
            'version' => '1.16.0.0',
            'reference' => '23e4ff33ea3e160d2d1f59a0e6050e4b0fb0eac1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/socket',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/stream' => array(
            'pretty_version' => 'v1.4.0',
            'version' => '1.4.0.0',
            'reference' => '1e5b0acb8fe55143b5b426817155190eb6f5b18d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/stream',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rhumsaa/uuid' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '4.9.0',
            ),
        ),
        'ringcentral/psr7' => array(
            'pretty_version' => '1.3.0',
            'version' => '1.3.0.0',
            'reference' => '360faaec4b563958b673fb52bbe94e37f14bc686',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ringcentral/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'sabberworm/php-css-parser' => array(
            'pretty_version' => 'v8.8.0',
            'version' => '8.8.0.0',
            'reference' => '3de493bdddfd1f051249af725c7e0d2c38fed740',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabberworm/php-css-parser',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'shardj/zf1-future' => array(
            'pretty_version' => '1.24.4',
            'version' => '1.24.4.0',
            'reference' => '3582cce4bcf2c820191be56cf17fdef0addf0771',
            'type' => 'library',
            'install_path' => __DIR__ . '/../shardj/zf1-future',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'simshaun/recurr' => array(
            'pretty_version' => 'v5.0.3',
            'version' => '5.0.3.0',
            'reference' => '7b136768d64f257065e38a804ee6d2f9af6ba6d1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../simshaun/recurr',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/deprecation-contracts' => array(
            'pretty_version' => 'v3.6.0',
            'version' => '3.6.0.0',
            'reference' => '63afe740e99a13ba87ec199bb07bbdee937a5b62',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/deprecation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-ctype' => array(
            'pretty_version' => 'v1.32.0',
            'version' => '1.32.0.0',
            'reference' => 'a3cc8b044a6ea513310cbd48ef7333b384945638',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-ctype',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-mbstring' => array(
            'pretty_version' => 'v1.32.0',
            'version' => '1.32.0.0',
            'reference' => '6d857f4d76bd4b343eac26d6b539585d2bc56493',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-mbstring',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php81' => array(
            'pretty_version' => 'v1.32.0',
            'version' => '1.32.0.0',
            'reference' => '4a4cfc2d253c21a5ad0e53071df248ed48c6ce5c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php81',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php83' => array(
            'pretty_version' => 'v1.32.0',
            'version' => '1.32.0.0',
            'reference' => '2fb86d65e2d424369ad2905e83b236a8805ba491',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php83',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php84' => array(
            'pretty_version' => 'v1.32.0',
            'version' => '1.32.0.0',
            'reference' => '000df7860439609837bbe28670b0be15783b7fbf',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php84',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'tedivm/jshrink' => array(
            'pretty_version' => 'v1.7.0',
            'version' => '1.7.0.0',
            'reference' => '7a35f5a4651ca2ce77295eb8a3b4e133ba47e19e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../tedivm/jshrink',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'webmozart/assert' => array(
            'pretty_version' => '1.11.0',
            'version' => '1.11.0.0',
            'reference' => '11cb2199493b2f8a3b53e7f19068fc6aac760991',
            'type' => 'library',
            'install_path' => __DIR__ . '/../webmozart/assert',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'wikimedia/less.php' => array(
            'pretty_version' => 'v3.2.1',
            'version' => '3.2.1.0',
            'reference' => '0d5b30ba792bdbf8991a646fc9c30561b38a5559',
            'type' => 'library',
            'install_path' => __DIR__ . '/../wikimedia/less.php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'zendframework/zendframework1' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '>=1.12.20',
            ),
        ),
    ),
);
